Documentation
¶
Index ¶
- func Bash(command string) (string, error)
- func BashWithContext(ctx context.Context, command string) (string, error)
- func DefineBashTool() types.Tool
- func DefineHTTPTool() types.Tool
- func DefineReadLocal(dirs ...fs.FS) types.Tool
- func DefineTavilySearch() types.Tool
- func ReadFS(root fs.FS, path string) (rw string, e error)
- func TavilySearch(ctx context.Context, query string) (string, error)
- func TavilySearchWithLimit(ctx context.Context, query string, maxResults int) (string, error)
- func TavilySearchWithLimitAndURL(ctx context.Context, query string, maxResults int, apiURL string) (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Bash ¶
Bash executes a shell command and returns its combined stdout and stderr. This is the universal tool for: - File operations (cat, grep, echo, find, etc.) - Script execution (python3, node, npx tsx, bash) - Git operations - Package management (npm, pip, etc.)
func BashWithContext ¶ added in v1.7.2
BashWithTimeout executes a shell command with a custom timeout.
func DefineTavilySearch ¶
func TavilySearch ¶
TavilySearch performs a web search using the Tavily API.
func TavilySearchWithLimit ¶
TavilySearchWithLimit performs a web search using the Tavily API with a custom result limit.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.